@@ -23,7 +23,7 @@
 #' @param show_col_types Logical. If \code{TRUE}, if the \code{verbose} argument is also \code{TRUE}, the columns of the raw dataset are shown during the download. \code{FALSE} by default.
 #'
 #'
-#' @source  \href{https://dati.istruzione.it/opendata/opendata/catalogo/elements1/?area=Edilizia+Scolastica}{Homepage}
+#' @source  <https://dati.istruzione.it/opendata/opendata/catalogo/elements1/?area=Edilizia+Scolastica>
 #'
 #' @details
 #' This function downloads the raw data; missing observations are not edited; all variables are characters.
@@ -131,8 +131,16 @@ Get_DB_MIUR <- function(Year = 2023, verbose = TRUE, input_Registry = NULL,
 
     if (httr::http_type(response) %in% c("application/csv", "text/csv", "application/octet-stream")) {
       if(verbose){
-        dat <- readr::read_csv(rawToChar(response$content), show_col_types = FALSE)
-        cat("CSV file downloaded:", link, " ... ")
+        content <- rawToChar(response$content)
+        if(nchar(content)==0){
+          message("Empty file. Operation aborted.
+        There seems to be something wrong with the website.
+        Please contact the maintainer, maybe it could help. \n")
+          return(NULL)
+        } else {
+          dat <- readr::read_csv(rawToChar(content), show_col_types = FALSE)
+          cat("CSV file downloaded:", link, " ... ")
+        }
       } else {
         suppressMessages(dat <- readr::read_csv(rawToChar(response$content)))
       }
