@@ -21,10 +21,12 @@
 #' \code{NULL} by default
 #' @param autoAbort Logical. Whether to automatically abort the operation and return NULL in case of missing internet connection or server response errors. \code{FALSE} by default.
 #'
-#' @source \href{https://dati.istruzione.it/opendata/opendata/catalogo/elements1/leaf/?area=Edilizia+Scolastica&datasetId=DS0101EDIANAGRAFESTA2021}{Buildings registry (2021 onwards)};
-#'  \href{https://dati.istruzione.it/opendata/opendata/catalogo/elements1/leaf/?area=Edilizia+Scolastica&datasetId=DS0200EDIANAGRAFESTA}{Buindings registry(until 2019)};
-#'   \href{https://dati.istruzione.it/opendata/opendata/catalogo/elements1/?area=Scuole}{Schools registry}
-#'
+#' @source
+#'  \itemize{
+#'    \item <https://dati.istruzione.it/opendata/opendata/catalogo/elements1/leaf/?area=Edilizia+Scolastica&datasetId=DS0101EDIANAGRAFESTA2021> For Buildings registry (2021 onwards);
+#'    \item <https://dati.istruzione.it/opendata/opendata/catalogo/elements1/leaf/?area=Edilizia+Scolastica&datasetId=DS0200EDIANAGRAFESTA> For Buindings registry(until 2019);
+#'    \item <https://dati.istruzione.it/opendata/opendata/catalogo/elements1/?area=Scuole> For Schools registry
+#'   }
 #'
 #' @return An object of class \code{list}, including 4 elements:
 #' \itemize{
@@ -86,8 +88,7 @@ Get_School2mun <- function(Year = 2023, show_col_types = FALSE, verbose = TRUE,
 
     if(is.null(homepage)){
       attempt <- attempt + 1
-      message("Operation exited with status: ", status, "; operation repeated (",
-              10 - attempt, " attempts left)")
+      message(10 - attempt, " attempts left)")
     }
     if(attempt >= 10) {
       message("Maximum attempts reached. Abort. We apologise for the inconvenience")
@@ -149,7 +150,15 @@ Get_School2mun <- function(Year = 2023, show_col_types = FALSE, verbose = TRUE,
     }
 
     if (httr::http_type(response) %in% c("application/csv", "text/csv", "application/octet-stream")) {
-      input_Registry1 <- readr::read_csv(rawToChar(response$content), show_col_types = FALSE)
+      content <- rawToChar(response$content)
+      if(nchar(content)==0){
+        message("Empty file. Operation aborted.
+        There seems to be something wrong with the website.
+        Please contact the maintainer, maybe it could help. \n")
+        return(NULL)
+      } else {
+        input_Registry1 <- readr::read_csv(rawToChar(response$content), show_col_types = FALSE)
+      }
     } else {
       message(paste("Wrong file type:", httr::http_type(response)) )
       message("Failed to download and process:", file_to_download, "\n")
